# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: schedule/v1/event.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'schedule/v1/event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import action_pb2 as schedule_dot_v1_dot_action__pb2
from . import rrule_pb2 as schedule_dot_v1_dot_rrule__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17schedule/v1/event.proto\x12\x0bschedule.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18schedule/v1/action.proto\x1a\x17schedule/v1/rrule.proto\",\n\x06\x45vents\x12\"\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x12.schedule.v1.Event\"\xa4\x03\n\x05\x45vent\x12\x33\n\x0b\x65vent_start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x02\x18\x01\x12\x16\n\x0e\x65vent_start_dt\x18\x05 \x01(\t\x12\x36\n\tevent_end\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x02\x18\x01H\x00\x88\x01\x01\x12\x19\n\x0c\x65vent_end_dt\x18\x06 \x01(\tH\x01\x88\x01\x01\x12&\n\x05rrule\x18\x03 \x01(\x0b\x32\x12.schedule.v1.RRuleH\x02\x88\x01\x01\x12#\n\x06\x61\x63tion\x18\x04 \x01(\x0b\x32\x13.schedule.v1.Action\x12\x36\n\x0eremaining_time\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationH\x03\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\x08 \x01(\x08H\x04\x88\x01\x01\x12\x11\n\x04name\x18\t \x01(\tH\x05\x88\x01\x01\x42\x0c\n\n_event_endB\x0f\n\r_event_end_dtB\x08\n\x06_rruleB\x11\n\x0f_remaining_timeB\t\n\x07_activeB\x07\n\x05_name\"\xee\x02\n\nEventError\x12=\n\x13missing_event_start\x18\x01 \x01(\x0b\x32\x1e.schedule.v1.MissingEventStartH\x00\x12=\n\x13invalid_event_start\x18\x02 \x01(\x0b\x32\x1e.schedule.v1.InvalidEventStartH\x00\x12\x39\n\x11invalid_event_end\x18\x03 \x01(\x0b\x32\x1c.schedule.v1.InvalidEventEndH\x00\x12\x32\n\rinvalid_rrule\x18\x04 \x01(\x0b\x32\x19.schedule.v1.InvalidRRuleH\x00\x12\x34\n\x0emissing_action\x18\x05 \x01(\x0b\x32\x1a.schedule.v1.MissingActionH\x00\x12\x34\n\x0einvalid_action\x18\x06 \x01(\x0b\x32\x1a.schedule.v1.InvalidActionH\x00\x42\x07\n\x05\x65rror\"\x13\n\x11MissingEventStart\"\x13\n\x11InvalidEventStart\"\x11\n\x0fInvalidEventEnd\"\xa0\x03\n\x0cInvalidRRule\x12\x45\n\x10invalid_argument\x18\x01 \x01(\x0b\x32).schedule.v1.InvalidRRule.InvalidArgumentH\x00\x12=\n\x0cparser_error\x18\x02 \x01(\x0b\x32%.schedule.v1.InvalidRRule.ParserErrorH\x00\x12\x45\n\x10validation_error\x18\x03 \x01(\x0b\x32).schedule.v1.InvalidRRule.ValidationErrorH\x00\x12\x39\n\niter_error\x18\x04 \x01(\x0b\x32#.schedule.v1.InvalidRRule.IterErrorH\x00\x1a\x11\n\x0fInvalidArgument\x1a\"\n\x0bParserError\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x1a&\n\x0fValidationError\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x1a \n\tIterError\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\tB\x07\n\x05\x65rror\"\x0f\n\rMissingAction\"\x0f\n\rInvalidActionBx\n\x1d\x63om.aira.contract.schedule.v1B\nEventProtoP\x01\xa2\x02\x03SXX\xaa\x02\x0bSchedule.V1\xca\x02\x0bSchedule\\V1\xe2\x02\x17Schedule\\V1\\GPBMetadata\xea\x02\x0cSchedule::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'schedule.v1.event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.aira.contract.schedule.v1B\nEventProtoP\001\242\002\003SXX\252\002\013Schedule.V1\312\002\013Schedule\\V1\342\002\027Schedule\\V1\\GPBMetadata\352\002\014Schedule::V1'
  _globals['_EVENT'].fields_by_name['event_start']._loaded_options = None
  _globals['_EVENT'].fields_by_name['event_start']._serialized_options = b'\030\001'
  _globals['_EVENT'].fields_by_name['event_end']._loaded_options = None
  _globals['_EVENT'].fields_by_name['event_end']._serialized_options = b'\030\001'
  _globals['_EVENTS']._serialized_start=156
  _globals['_EVENTS']._serialized_end=200
  _globals['_EVENT']._serialized_start=203
  _globals['_EVENT']._serialized_end=623
  _globals['_EVENTERROR']._serialized_start=626
  _globals['_EVENTERROR']._serialized_end=992
  _globals['_MISSINGEVENTSTART']._serialized_start=994
  _globals['_MISSINGEVENTSTART']._serialized_end=1013
  _globals['_INVALIDEVENTSTART']._serialized_start=1015
  _globals['_INVALIDEVENTSTART']._serialized_end=1034
  _globals['_INVALIDEVENTEND']._serialized_start=1036
  _globals['_INVALIDEVENTEND']._serialized_end=1053
  _globals['_INVALIDRRULE']._serialized_start=1056
  _globals['_INVALIDRRULE']._serialized_end=1472
  _globals['_INVALIDRRULE_INVALIDARGUMENT']._serialized_start=1336
  _globals['_INVALIDRRULE_INVALIDARGUMENT']._serialized_end=1353
  _globals['_INVALIDRRULE_PARSERERROR']._serialized_start=1355
  _globals['_INVALIDRRULE_PARSERERROR']._serialized_end=1389
  _globals['_INVALIDRRULE_VALIDATIONERROR']._serialized_start=1391
  _globals['_INVALIDRRULE_VALIDATIONERROR']._serialized_end=1429
  _globals['_INVALIDRRULE_ITERERROR']._serialized_start=1431
  _globals['_INVALIDRRULE_ITERERROR']._serialized_end=1463
  _globals['_MISSINGACTION']._serialized_start=1474
  _globals['_MISSINGACTION']._serialized_end=1489
  _globals['_INVALIDACTION']._serialized_start=1491
  _globals['_INVALIDACTION']._serialized_end=1506
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/set_diagnostic_poll_period.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/command/v1/set_diagnostic_poll_period.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<device/heat_pump/command/v1/set_diagnostic_poll_period.proto\x12\x1b\x64\x65vice.heat_pump.command.v1\"6\n\x17SetDiagnosticPollPeriod\x12\x1b\n\x13poll_period_minutes\x18\x01 \x01(\rB\xd8\x01\n-com.aira.contract.device.heat_pump.command.v1B\x1cSetDiagnosticPollPeriodProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.set_diagnostic_poll_period_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-com.aira.contract.device.heat_pump.command.v1B\034SetDiagnosticPollPeriodProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_SETDIAGNOSTICPOLLPERIOD']._serialized_start=93
  _globals['_SETDIAGNOSTICPOLLPERIOD']._serialized_end=147
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/ble/v1/main_pump_flow.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/ble/v1/main_pump_flow.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,device/heat_pump/ble/v1/main_pump_flow.proto\x12\x17\x64\x65vice.heat_pump.ble.v1\x1a\x1egoogle/protobuf/duration.proto\"\xd8\x01\n\x0cMainPumpFlow\x12=\n\x1aremaining_circulation_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x41\n\tflow_data\x18\x02 \x03(\x0b\x32..device.heat_pump.ble.v1.MainPumpFlow.FlowData\x1a\x46\n\x08\x46lowData\x12,\n\ttimestamp\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0c\n\x04\x66low\x18\x02 \x01(\x02\"p\n\x17GetMainPumpFlowResponse\x12\x42\n\x0emain_pump_flow\x18\x01 \x01(\x0b\x32%.device.heat_pump.ble.v1.MainPumpFlowH\x00\x88\x01\x01\x42\x11\n\x0f_main_pump_flow*\xa3\x01\n\x11MainPumpFlowState\x12$\n MAIN_PUMP_FLOW_STATE_UNSPECIFIED\x10\x00\x12$\n MAIN_PUMP_FLOW_STATE_NOT_STARTED\x10\x01\x12#\n\x1fMAIN_PUMP_FLOW_STATE_COLLECTING\x10\x02\x12\x1d\n\x19MAIN_PUMP_FLOW_STATE_DONE\x10\x03\x42\xb9\x01\n)com.aira.contract.device.heat_pump.ble.v1B\x11MainPumpFlowProtoP\x01\xa2\x02\x03\x44HB\xaa\x02\x16\x44\x65vice.HeatPump.Ble.V1\xca\x02\x16\x44\x65vice\\HeatPump\\Ble\\V1\xe2\x02\"Device\\HeatPump\\Ble\\V1\\GPBMetadata\xea\x02\x19\x44\x65vice::HeatPump::Ble::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.ble.v1.main_pump_flow_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.aira.contract.device.heat_pump.ble.v1B\021MainPumpFlowProtoP\001\242\002\003DHB\252\002\026Device.HeatPump.Ble.V1\312\002\026Device\\HeatPump\\Ble\\V1\342\002\"Device\\HeatPump\\Ble\\V1\\GPBMetadata\352\002\031Device::HeatPump::Ble::V1'
  _globals['_MAINPUMPFLOWSTATE']._serialized_start=439
  _globals['_MAINPUMPFLOWSTATE']._serialized_end=602
  _globals['_MAINPUMPFLOW']._serialized_start=106
  _globals['_MAINPUMPFLOW']._serialized_end=322
  _globals['_MAINPUMPFLOW_FLOWDATA']._serialized_start=252
  _globals['_MAINPUMPFLOW_FLOWDATA']._serialized_end=322
  _globals['_GETMAINPUMPFLOWRESPONSE']._serialized_start=324
  _globals['_GETMAINPUMPFLOWRESPONSE']._serialized_end=436
# @@protoc_insertion_point(module_scope)


from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))
with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '0.1.4'
DESCRIPTION = 'Python client for Aira Home, initially developed for Homeassistant'

# Setting up
setup(
    name="pyairahome",
    version=VERSION,
    author="Invy55 (Marco)",
    author_email="<marco@invy55.win>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    url="https://github.com/Invy55/pyairahome",
    packages=find_packages(),
    install_requires=['pycognito>=2024.5.1', 'grpcio>=1.72.0', 'protobuf>=6.31.1'],
    keywords=['python', 'aira', 'airahome', 'aira home', 'api', 'wrapper'],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import devices_pb2 as device_dot_v1_dot_devices__pb2

GRPC_GENERATED_VERSION = '1.72.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in device/v1/devices_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class DevicesServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetDevices = channel.unary_unary(
                '/device.v1.DevicesService/GetDevices',
                request_serializer=device_dot_v1_dot_devices__pb2.GetDevicesRequest.SerializeToString,
                response_deserializer=device_dot_v1_dot_devices__pb2.GetDevicesResponse.FromString,
                _registered_method=True)
        self.GetDeviceDetails = channel.unary_unary(
                '/device.v1.DevicesService/GetDeviceDetails',
                request_serializer=device_dot_v1_dot_devices__pb2.GetDeviceDetailsRequest.SerializeToString,
                response_deserializer=device_dot_v1_dot_devices__pb2.GetDeviceDetailsResponse.FromString,
                _registered_method=True)
        self.CreateDeviceDetails = channel.unary_unary(
                '/device.v1.DevicesService/CreateDeviceDetails',
                request_serializer=device_dot_v1_dot_devices__pb2.CreateDeviceDetailsRequest.SerializeToString,
                response_deserializer=device_dot_v1_dot_devices__pb2.CreateDeviceDetailsResponse.FromString,
                _registered_method=True)
        self.StreamDevices = channel.unary_stream(
                '/device.v1.DevicesService/StreamDevices',
                request_serializer=device_dot_v1_dot_devices__pb2.StreamDevicesRequest.SerializeToString,
                response_deserializer=device_dot_v1_dot_devices__pb2.StreamDevicesResponse.FromString,
                _registered_method=True)
        self.GetStates = channel.unary_unary(
                '/device.v1.DevicesService/GetStates',
                request_serializer=device_dot_v1_dot_devices__pb2.GetStatesRequest.SerializeToString,
                response_deserializer=device_dot_v1_dot_devices__pb2.GetStatesResponse.FromString,
                _registered_method=True)
        self.StreamStates = channel.unary_stream(
                '/device.v1.DevicesService/StreamStates',
                request_serializer=device_dot_v1_dot_devices__pb2.StreamStatesRequest.SerializeToString,
                response_deserializer=device_dot_v1_dot_devices__pb2.StreamStatesResponse.FromString,
                _registered_method=True)


class DevicesServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetDevices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeviceDetails(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDeviceDetails(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamDevices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamStates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DevicesServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetDevices': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDevices,
                    request_deserializer=device_dot_v1_dot_devices__pb2.GetDevicesRequest.FromString,
                    response_serializer=device_dot_v1_dot_devices__pb2.GetDevicesResponse.SerializeToString,
            ),
            'GetDeviceDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeviceDetails,
                    request_deserializer=device_dot_v1_dot_devices__pb2.GetDeviceDetailsRequest.FromString,
                    response_serializer=device_dot_v1_dot_devices__pb2.GetDeviceDetailsResponse.SerializeToString,
            ),
            'CreateDeviceDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDeviceDetails,
                    request_deserializer=device_dot_v1_dot_devices__pb2.CreateDeviceDetailsRequest.FromString,
                    response_serializer=device_dot_v1_dot_devices__pb2.CreateDeviceDetailsResponse.SerializeToString,
            ),
            'StreamDevices': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamDevices,
                    request_deserializer=device_dot_v1_dot_devices__pb2.StreamDevicesRequest.FromString,
                    response_serializer=device_dot_v1_dot_devices__pb2.StreamDevicesResponse.SerializeToString,
            ),
            'GetStates': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStates,
                    request_deserializer=device_dot_v1_dot_devices__pb2.GetStatesRequest.FromString,
                    response_serializer=device_dot_v1_dot_devices__pb2.GetStatesResponse.SerializeToString,
            ),
            'StreamStates': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamStates,
                    request_deserializer=device_dot_v1_dot_devices__pb2.StreamStatesRequest.FromString,
                    response_serializer=device_dot_v1_dot_devices__pb2.StreamStatesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'device.v1.DevicesService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('device.v1.DevicesService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DevicesService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetDevices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.v1.DevicesService/GetDevices',
            device_dot_v1_dot_devices__pb2.GetDevicesRequest.SerializeToString,
            device_dot_v1_dot_devices__pb2.GetDevicesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDeviceDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.v1.DevicesService/GetDeviceDetails',
            device_dot_v1_dot_devices__pb2.GetDeviceDetailsRequest.SerializeToString,
            device_dot_v1_dot_devices__pb2.GetDeviceDetailsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateDeviceDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.v1.DevicesService/CreateDeviceDetails',
            device_dot_v1_dot_devices__pb2.CreateDeviceDetailsRequest.SerializeToString,
            device_dot_v1_dot_devices__pb2.CreateDeviceDetailsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamDevices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/device.v1.DevicesService/StreamDevices',
            device_dot_v1_dot_devices__pb2.StreamDevicesRequest.SerializeToString,
            device_dot_v1_dot_devices__pb2.StreamDevicesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.v1.DevicesService/GetStates',
            device_dot_v1_dot_devices__pb2.GetStatesRequest.SerializeToString,
            device_dot_v1_dot_devices__pb2.GetStatesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/device.v1.DevicesService/StreamStates',
            device_dot_v1_dot_devices__pb2.StreamStatesRequest.SerializeToString,
            device_dot_v1_dot_devices__pb2.StreamStatesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)